pub struct InlineConfig { /* private fields */ }Expand description
An inline config. Keeps track of disabled ranges.
This is a list of Inline Config items for locations in a source file. This is
usually acquired by parsing the comments for an forgefmt: items.
See Comments::parse_inline_config_items for
details.
Implementations
Sourceimpl InlineConfig
impl InlineConfig
Sourcepub fn new(
items: impl IntoIterator<Item = (Loc, InlineConfigItem)>,
src: &str,
) -> Self
pub fn new( items: impl IntoIterator<Item = (Loc, InlineConfigItem)>, src: &str, ) -> Self
Build a new inline config with an iterator of inline config items and their locations in a source file
Sourcepub fn is_disabled(&self, loc: Loc) -> bool
pub fn is_disabled(&self, loc: Loc) -> bool
Check if the location is in a disabled range