pub struct FormatterConfig {Show 14 fields
pub line_length: usize,
pub tab_width: usize,
pub bracket_spacing: bool,
pub int_types: IntTypes,
pub multiline_func_header: MultilineFuncHeaderStyle,
pub quote_style: QuoteStyle,
pub number_underscore: NumberUnderscore,
pub hex_underscore: HexUnderscore,
pub single_line_statement_blocks: SingleLineBlockStyle,
pub override_spacing: bool,
pub wrap_comments: bool,
pub ignore: Vec<String>,
pub contract_new_lines: bool,
pub sort_imports: bool,
}Expand description
Contains the config and rule set
Fields
line_length: usizeMaximum line length where formatter will try to wrap the line
tab_width: usizeNumber of spaces per indentation level
bracket_spacing: boolPrint spaces between brackets
int_types: IntTypesStyle of uint/int256 types
multiline_func_header: MultilineFuncHeaderStyleStyle of multiline function header in case it doesn’t fit
quote_style: QuoteStyleStyle of quotation marks
number_underscore: NumberUnderscoreStyle of underscores in number literals
hex_underscore: HexUnderscoreStyle of underscores in hex literals
single_line_statement_blocks: SingleLineBlockStyleStyle of single line blocks in statements
override_spacing: boolPrint space in state variable, function and modifier override attribute
wrap_comments: boolWrap comments on line_length reached
ignore: Vec<String>Globs to ignore
contract_new_lines: boolAdd new line at start and end of contract declarations
sort_imports: boolSort import statements alphabetically in groups (a group is separated by a newline).